%
%   This function multiplies a scalar pseudo polynomial of 
%    degree n on a infinite matrix pseudo polynomial. One
%    application is multiplying an AR & MA process
%
%       mu(z) * F(z) = H(z)
%
%       where mu(z) = mu0 + mu1(z + z^-1) + ... + mun(z^n + z^-n)
%              F(z) = F0 + F1 z + F1' z^-1 + ... 
%              H(z) = H0 + H1 z + H1' z^-1 + ...
%              Fk & Hk are m-by-m matrices  
%
%       Input:     muvec = [mu0 mu1 ... mun]'
%               F(:,:,k) = Fk  k = 0...N+n
%       Output: H(:,:,k) = Hk  k = 0...N
%
function  H = ARtimesMA(muvec,F)

n = length(muvec) - 1;
[ m m N ] = size(F);
N = N - n - 1;
muvec(1) = muvec(1)/2;

H = kron(muvec(:)',eye(m)) * ( BlkHankel(F(:,:,1:n+1),F(:,:,n+1:end)) ...
    + BlkToeplitz(BlkTrans(F(:,:,1:n+1)),F(:,:,1:N+1)));
H = reshape(H,m,m,N+1);
