%
%   This function transforms back an interpolant f(u) to f(z) when
%
%            az + b                   b - du
%       u = --------     <==>    z = --------   (ad - bc != 0)
%            cz + d                   cu - a
%
%   Input:  domaintrans  -  Transformation parameters
%           interpolant  -  Interpolating function
%
%   Output: interpolantnew  -  New interpolating function
%
function interpolant = BilinearDomain(trans,interpolant)

I = eye(size(interpolant.A,1));
Dnew = inv(trans.d*I-trans.b*interpolant.A);
Anew = Dnew*(-trans.c*I + trans.a*interpolant.A);
Bnew = Dnew*interpolant.B;
Cnew = interpolant.C * (trans.b*Anew + trans.a*I);
Dnew = interpolant.D + trans.b*interpolant.C*Bnew;

interpolant.A = Anew;
interpolant.B = Bnew;
interpolant.C = Cnew;
interpolant.D = Dnew;