%
%   This script runs the inverted pendulum example from [1] using 
%    the design procedure of [2].
%
%   [1]. E. J. Davison, editor, "Benchmark problems for control system 
%         design", May 1990. Report from the IFAC theory committee.
%
%   [2]. A. Blomqvist, A. Lindquist & R. Nagamune, "Matrix-valued 
%         Nevanlinna-Pick interpolation with complexity constraint: an
%         optimization approach", preprint 2002.
%
clear all, format compact

%
%   Tuning parameters
%
indata.flag = 2;
indata.addpoints = [ 1e8 2e-5];
indata.gamma = 10^(15/20);
indata.kappa = 0.93;
indata.speczeros = [ 10i 10 ];
indata.maxdist = 0.95;
indata.lambda = 1;

vec = { { {[ 4e0*i 4e0*[1 1 1] ]} {[ 10^(40/20) ]} {[ 0.95 ]} }  ...
        { {[ 8e0*i 8e0*[1 1 1] ]}  {[ 10^(40/20) ]} {[ 0.995 ]} } };
xvec = logspace(-2,2,1000);
figure(2), clf, hold on

S = {};
for x = vec

    indata.speczeros = x{1}{1}{1}; 
    indata.gamma = x{1}{2}{1}; 
    indata.maxdist = x{1}{3}{1}; 
    
    %
    %   Solve the problem using the algorithm of [2]
    %
    outdata = ExInvPendulum(indata);

    [S{end+1} xvec] = sigma(outdata.clsysNPDC,xvec);
    figure(2)
    sigma(outdata.sysKNPDC,xvec)
end

%
%   Plotting the frequency response
%
figure(1), clf
semilogx(xvec,20*log10(S{1}(1,:)),'k-.'), hold on
semilogx(xvec,20*log10(S{2}(1,:)),'k-')
semilogx(xvec,20*log10(S{1}(2,:)),'k-.'), hold on
semilogx(xvec,20*log10(S{2}(2,:)),'k-')
xlabel('Frequency, rad/s')
ylabel('Singular values, dB')
title('Sensitivity functions')
legend('Low frequency spectral zeros','High frequency spectral zeros',4)

%
%   Printing
%
printflag = 1;
if printflag
    papersize = [ 10 7.5 ];
    width = 7;
    height = 5;
    left = (papersize(1)- width) / 2;
    bottom = (papersize(2)- height) / 2;
    myfiguresize = [left, bottom, width, height];
    myfontsize = 12;
    myfontweight = 'bold';

    figure(1)
    set(gcf,'Units','centimeters')
    set(gcf, 'PaperPosition', myfiguresize);
    ChangeTextStyle(gcf,myfontsize,myfontweight);
    print sensitivitypend -deps
    
    figure(2)
    set(gcf,'Units','centimeters')
    set(gcf, 'PaperPosition', myfiguresize);
    ChangeTextStyle(gcf,myfontsize,myfontweight);
    print controllerpend -deps
        
end