%
%   This function runs the inverted pendelum example for a
%    set of parameters
%
function outdata = ExInvPendulum(indata);

% Revive indata
flag = indata.flag;
gamma = indata.gamma;
kappa = indata.kappa;
speczeros = indata.speczeros;
maxdist = indata.maxdist;
lambda = indata.lambda;
addpoints = indata.addpoints;

%
%   Plant
%
if flag == 1 
    A = [ 0 1 ; 9.8 0 ];
    B = [ 0; 1 ];
    C = [ 1 0 ];
    D = [ 0 ];
    sys = ss(A,B,C,D);
else
    A = [ 0 1 0 0; 9.8 0 -9.8 0; 0 0 0 1; -9.8 0 29.4 0 ];
    B = [ 0 0; 1 -2; 0 0; -2 5 ];
    C = [ 1 0 0 0; 0 0 1 0 ];
    D = [ 0 0; 0 0 ];
    sys = ss(A,B,C,D);
end
I = eye(size(D,1));
nD = size(D);
Gsys = [ I -sys; I -sys ];

%
%   Perform the NPDC design
%

% Stabilize
if flag == 1
    newpoles = eig(A) - [ 6 0 ]';
else
    newpoles = eig(A) - [ 8 4 0 0 ]';
end
H = place(A',C(:,:)',newpoles)';
F = place(A,-B(:,:),newpoles);

Dtilde = 1e-3*I;
AF = A+B*F;
AH = A-H*C;  % C2 = -C !!
sysT1 = ss([AF, -B*F; zeros(size(A)) AH],[zeros(size(B)); H],[-C-Dtilde*F Dtilde*F],I);
sysT2 = ss(AF,B,-C-Dtilde*F,-Dtilde);
sysT3 = ss(AH,H,-C,I);
sysT1 = minreal(sysT1);
sysT2 = minreal(sysT2);
sysT3 = minreal(sysT3);
[sysT2in, sysT2inp, sysT2out] = iofr(sysT2);
[sysT3in, sysT3inp, sysT3out] = iofc(sysT3);
sysT2in = RemoveSmall(sysT2in,1e-8);
sysT2in = -minreal(sysT2in);
sysT2out = -minreal(sysT2out);
sysT2in = ss([],[],[],I);%minreal(sysT2in);
sysT2out = sysT2;%minreal(sysT2out);
sysT3in = minreal(sysT3in);
sysT3out = minreal(sysT3out);

% Get interpolation data
svec = - [ pole(sysT2in); pole(sysT3in) ];
sysphi = ss(zpk(svec,-svec,1));
sysT1hat = minreal(sysphi*inv(sysT2in)*sysT1*inv(sysT3in));

Ws = {};
for s = svec'
    Ws{end+1}{1} = sysT1hat.c*inv(eye(size(sysT1hat.a))*s-sysT1hat.a)*sysT1hat.b+sysT1hat.d;
end

% Add interpolation conditions
svec = [  svec' addpoints ];
Ws = [ Ws {[{0*I} ]} {[{0*I} ]}];

% Get strictly proper controller, S''(inf) = 0
sysT2ininv = inv(sysT2in);
sysT3ininv = inv(sysT3in);
phim = GetMarkov(sysphi,3);
T2ininvm = GetMarkov(sysT2ininv,3);
T3ininvm = GetMarkov(sysT3ininv,3);
Sm(:,:,1) = I; Sm(:,:,2) = 0*I; Sm(:,:,3) = 0*I;
Shatm = MPolyMult(reshape(phim,1,1,3),reshape(T2ininvm,flag,flag,3));
Shatm = MatPolyMult(Shatm,Sm);
Shatm = MatPolyMult(Shatm,reshape(T3ininvm,flag,flag,3));

% Transform from continuous time to standard form
domaintrans = GetBlTrans(kappa,-kappa,1,1);
rangetrans = GetBlTrans(1,gamma,-1,gamma);
scalingtrans = GetBlTrans(1,0,0,lambda);
s2ztrans = GetBlTrans(0,1,1,0);

interdatas = GetInterData(svec,Ws,speczeros,maxdist);
interdataz = BilinearDomainData(s2ztrans,interdatas);
W = interdataz.W;
W{end-1} = [ {Shatm(:,:,1)} {Shatm(:,:,2)} {Shatm(:,:,3)}];
interdataz = GetInterData(interdataz.z,W,interdataz.speczeros,maxdist);
interdata1 = BilinearDomainData(scalingtrans,interdataz);
interdata2 = BilinearDomainData(domaintrans,interdata1);
interdata3 = BilinearRangeData(rangetrans,interdata2);

% Solve NPDC
interpolant3 = NPDC(interdata3);
GetIntError(interpolant3,interdata3)

% Transform back
interpolant2 = BilinearRange(rangetrans,interpolant3);
GetIntError(interpolant2,interdata2)

interpolant1 = BilinearDomain(domaintrans,interpolant2);
GetIntError(interpolant1,interdata1)

interpolants = BilinearDomain(scalingtrans,interpolant1);
GetIntError(interpolants,interdataz)
%GetIntError2(interpolants,interdatas)

sysShat = ss(interpolants.A,interpolants.B,interpolants.C,interpolants.D);

tol = 1e-6;
sysS = minreal(inv(sysphi)*sysT2in*sysShat*sysT3in,tol);

% Get controller
syss2P=ss(A,A*B,C*A,C*A*B);
sysinvs2P=inv(syss2P);
if norm(-sysS.c*sysS.b) > 1e-6
    disp('S''(inf) not zero')
end
if norm(-sysS.c*sysS.a*sysS.b) > 1e-3
    disp('S''''(inf) not zero')
end
syss2I_S=ss(sysS.a,-sysS.a*sysS.b,sysS.c*sysS.a,-sysS.c*sysS.a*sysS.b);%zeros(nD));
sysinvS=inv(sysS);

sysKNPDC=minreal(series(sysinvS,series(syss2I_S,sysinvs2P)));
orderKNPDC = num2str(size(sysKNPDC.a,1));
disp(['Order of NPDC controller: ' orderKNPDC])

clsysNPDC = minreal(lft(Gsys,sysKNPDC));
orderSNPDC = num2str(size(clsysNPDC.a,1));
disp(['Order of NPDC sensitivity: ' orderSNPDC])

% Give outdata
outdata.sysKNPDC = sysKNPDC;
outdata.clsysNPDC = clsysNPDC;
outdata.sysShat = sysShat; 