%
%   This function returns an interpolant
%
%              [ A | B ]                 
%       F(z) = [-------] = Cz(I-Az)^-1B + D
%              [ C | D ]                 
%
%                      (   R*R   )-1
%       F(z) + F*(z) = ( ------- )
%                      ( rho*rho )
%
%   Input: R(:,:,k) = Rk
%          rho = [ rho0 ... rhon ]
%
%   Output: interpolant
%
function interpolant = GetInterpolant(R,rho)

% Sizes
[ m m ntilde] = size(R);

% Added by Anders 020524
while rho(1) == 0
    rho = [ rho(2:end) 0 ];
end

% Get Vinv
[VinvA,VinvB,VinvC,VinvD] = tfm2ss(reshape(R,m*m,ntilde),rho,m,m);

% Invert to get V
VD = inv(VinvD);
VB = -VinvB*VD;
VA = VinvA+VB*VinvC;
VC = VD*VinvC;
interpolant.sysV = ss(VA,VB,VC,VD,1);

% Get F given spectral factor V
P = dlyap(VA,VB*VB');
interpolant.A = VA;
interpolant.B = VA*P*VC'+VB*VD';
interpolant.C = VC;
interpolant.D = (VC*P*VC'+VD*VD')/2;
