%
%   This function determine the Pick matrix for the scalar multiple
%    (derivative) Nevanlinna-Pick / Caratheodory interpolation 
%    problems
%
%   Input: interdata - interpolation data set
%
%   Output: P - the Pick matrix
%
function P = GetPickMatrix(interdata)

z = interdata.z;
mw = interdata.mw;
A = [];
bb = [];
W = [];

for j = 1:length(z)
    if mw(j) == 1
        Asub = z(j);
        bsub = 1;
    else
        Asub = toeplitz([z(j) 1 zeros(1,mw(j)-2)],[z(j) zeros(1,mw(j)-1)]);
        bsub = [1 zeros(1,mw(j)-1)]';
    end
    Wvec = [];
    for l = 1:length(interdata.W{j})
        Wvec(:,:,l) = interdata.W{j}{l}.';
    end
    Wvec2 = zeros(size(Wvec));
    Wvec2(:,:,1) = Wvec(:,:,1);
    Wsub = BlkToeplitz(Wvec,Wvec2);
    A = blkdiag(A,Asub);
    bb = [bb; bsub];
    W = blkdiag(W,Wsub);
end

E = dlyap(conj(A),bb*bb');
E = kron(E.',eye(interdata.m));
P = W*E+E*W';