%
%   This function solves the inverse multivariate Yule-Walker
%    equation.
%
%   Input:  A(:,:,k) = Ak, k = 1..n  (A0 need not be Id)
%
%   Output: R(:,:,k) = Rk, k 0 1..n  
%
%   where           A(z) = A0 + A1*z + ... + An*z^n
%         (A(z)A*(z))^-1 = R0 + R1(z+z^-1) + ...
%
%   Should it be AA* or A*A ??
%
function R = InvMultivariateYuleWalker(A)

AA = A;

m = size(A,1);
n = size(A,3);
nm = n*m;

% Normalize
A0inv = inv(A(:,:,1));
for k = 1:n
    A(:,:,k) = A0inv*A(:,:,k);
end

% Construct coefficient matrices

B = sparse(nm,nm);
C = sparse(nm,nm);
C(end-m+1:end,1:m) = A(:,:,n)';
for k = m:m:nm-1
    B(end-k+1:end-k+m,end-k+1:end) = [ B(end-k+1+m:end-k+2*m,end-k+m+1:end) A(:,:,k/m)' ];
    C(end-k+1-m:end-k,1:k+m) = [ A(:,:,n-k/m)' C(end-k+1:end-k+m,1:k) ];
end

% Construct permutation indices
hvec = [];
for k = 1:m
    hvec = [ hvec k:m:m^2 ];
end
vec = [];
for k = 0:m^2:nm*m-1
    vec = [vec hvec+k];
end

Im = speye(m);
B = kron(B',Im);
C = kron(C',Im);

% Permutation of B
B = B(:,vec);

% RHS
D = zeros(nm*m,1);
D(1:m^2) = Im(:);

% Solve system
Rvec = (B+C)\D;

% Reorder to output format
Rvec = reshape(Rvec,m,m,n);
for k = 1:n
    R(:,:,k) = full(A0inv'*Rvec(:,:,k)*A0inv);
end

% %   Temp check

%B = repmat(0,[m m n]);
%B(:,:,1) = AA(:,:,1);

%L = blktoeplitz(B,AA)';

%B = reshape(reshape(AA,m,m*n)*L,m,m,n);
%B(:,:,1) = B(:,:,1) / 2;
%reshape(B,m,n*m)*(blkhankel




% 
% N = 10;
% AAvec = reshape(AA,m,nm);
% AAvec = AAvec(:,m+1:end);
% 
% for k = n+1:N
%     R(:,:,k) = - AAvec * reshape(R(:,:,k-1:-1:k-n+1),(n-1)*m,m);
% end
% 
% for z = 0.5*exp(i*(0:pi/3:6))
%     z
%     LHS = inv( (AA(:,:,1)+AA(:,:,2)*z+AA(:,:,3)*z^2) ...
%         *(AA(:,:,1)'+AA(:,:,2)'/z+AA(:,:,3)'/z^2));
%     RHS = R(:,:,1);
%     for k = 2:N
%         RHS = RHS + R(:,:,k-1)*(z^k+1/z^k);
%     end
%     diff = norm(LHS-RHS)
% end