%
%   This function multiplies two matrix polynomials
%
%       A(z) (*) B(z) = C(z)
%
%    where 
%      A(z) = A0 + A1 z + ... + An z^m
%      Ak is a p-by-q real matrix
%      B(z) = B0 + B1 z + ... + An z^n
%      Bk is a r-by-s real matrix
%      C(z) = C0 + C1 z + ... + An z^(n+m)
%      Ck is a pr-by-qs real matrix
%      (*) denotes the kronecker product
%
%   Input: A(:,:,k) = Ak
%          B(:,:,k) = Bk
%
%   Output: C(:,:,k) = Ck
%
function C = MPolyMult(A,B)

[ p q m ] = size(A);
[ r s n ] = size(B);

for pp = 1:p
    ppp = (pp-1)*p;
    for qq = 1:q
        qqq = (qq-1)*p;
        for rr = 1:r
            for ss = 1:s
                C(ppp+rr,qqq+ss,:) = conv(squeeze(A(pp,qq,:))', ...
                    squeeze(B(rr,ss,:))');
            end
        end
    end
end