%
%   This function multiplies two matrix polynomials
%
%       A(z) * B(z) = C(z)
%
%    where 
%      A(z) = A0 + A1 z + ... + An z^m
%      Ak is a p-by-q real matrix
%      B(z) = B0 + B1 z + ... + An z^n
%      Bk is a q-by-r real matrix
%      C(z) = C0 + C1 z + ... + An z^(n+m)
%      Ck is a pr-by-qs real matrix
%      * denotes the matrix product
%
%   Input: A(:,:,k) = Ak
%          B(:,:,k) = Bk
%
%   Output: C(:,:,k) = Ck
%
function C = mpolymult(A,B)

[ p q m ] = size(A);
[ s r n ] = size(B);

if q ~= s
    disp('In MatPolyMult: dimensions does not agree')
    return
end

B0 = zeros(s,r,m);
B0(:,:,1) = B(:,:,1);

C = reshape(reshape(A,p,q*m) * BlkToeplitz(B0,B),p,r,n);