%
%   This function reorders the matrices as
%
%       S(z) = p * R^-1 (*) R'  -->  
%          
%            p * (Vec R'^-1)(Vec R^-1)' = S~(z)
%
%    where R(z) = R0 + R1 z + ...
%          p(z) = p0 + p1 z + ... + pn z^n
%          S(z) = S0 + S1 z^-1 + ...
%          S~(z) = S~0 + S~1 z^-1 + ...
%          Rk is m-by-m
%          pk is scalar
%          Sk & S~k are m^2-by-m^2
%
%   Input: S(:,:,k) = Sk   k = 1...n
%
%   Output: S(:,:,k) = S~k   k = 1...n
%
function S = ReOrder1(S)

[ m2 m2 n ] = size(S);
m = sqrt(m2);

B = reshape(S,m2,m,m*n);
B = permute(B,[2 1 3]);
B = BlkTransSpec(B)';
S = reshape(B,m2,m2,n); 
  